( cd usr/bin ; rm -rf mldc )
( cd usr/bin ; ln -sf mlnet mldc )
( cd usr/bin ; rm -rf mlbt+gui )
( cd usr/bin ; ln -sf mlnet+gui mlbt+gui )
( cd usr/bin ; rm -rf mldonkey_gui )
( cd usr/bin ; ln -sf mlgui mldonkey_gui )
( cd usr/bin ; rm -rf mlslsk )
( cd usr/bin ; ln -sf mlnet mlslsk )
( cd usr/bin ; rm -rf mlslsk+gui )
( cd usr/bin ; ln -sf mlnet+gui mlslsk+gui )
( cd usr/bin ; rm -rf mldc+gui )
( cd usr/bin ; ln -sf mlnet+gui mldc+gui )
( cd usr/bin ; rm -rf mlbt )
( cd usr/bin ; ln -sf mlnet mlbt )
( cd usr/bin ; rm -rf mlgnut )
( cd usr/bin ; ln -sf mlnet mlgnut )
( cd usr/bin ; rm -rf mlgnut+gui )
( cd usr/bin ; ln -sf mlnet+gui mlgnut+gui )
( cd usr/bin ; rm -rf mldonkey )
( cd usr/bin ; ln -sf mlnet mldonkey )
( cd usr/bin ; rm -rf mldonkey+gui )
( cd usr/bin ; ln -sf mlnet+gui mldonkey+gui )
